=======
History
=======

0.1.0 (2019-05-26)
------------------

* First release on PyPI.

0.1.1 (2019-06-04)
------------------

* Refactor import structure.
* Adding checks on using 'proba' and fallback to 'predict' if needed.

0.1.2 (2019-06-19)
------------------

* Added option to use different folds in training different layers in Stack.
